<?php
namespace TAV3V2\Helpers;

use TAV3V2\Abstracts\Abstract_Main_Plugin_Class;

if ( !defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Model that houses all the plugin constants.
 * Note as much as possible, we need to make this class succinct as the only purpose of this is to house all the constants that is utilized by the plugin.
 * Therefore we omit class member comments and minimize comments as much as possible.
 * In fact the only verbouse comment here is this comment you are reading right now.
 * And guess what, it just got worse coz now this comment takes 5 lines instead of 3.
 *
 * @since 1.0.0
 */
class Plugin_Constants {

    /*
    |--------------------------------------------------------------------------
    | Class Properties
    |--------------------------------------------------------------------------
    */

    private static $_instance;

    // Plugin configuration constants
    const TOKEN                   = 'wpb';
    const INSTALLED_VERSION       = 'tav3v2_installed_version';
    const VERSION                 = '1.0.2';
    const TEXT_DOMAIN             = 'tav3v2';
    const THEME_TEMPLATE_PATH     = 'tav3v2';
    const META_DATA_PREFIX        = '_ta_';
    const DOWNGRADE_COMPLETE_FLAG = 'ta_downgrade_complete_flag';
    const MIGRATION_COMPLETE_FLAG = 'ta_migration_complete_flag';

    // Settings Constants

    // Help Section
    const CLEAN_UP_PLUGIN_OPTIONS = 'tav3v2_clean_up_plugin_options';
    

    
    
    /*
    |--------------------------------------------------------------------------
    | Class Methods
    |--------------------------------------------------------------------------
    */

    public function __construct( Abstract_Main_Plugin_Class $main_plugin ) {

        // Path constants
        $this->_MAIN_PLUGIN_FILE_PATH = WP_PLUGIN_DIR . DIRECTORY_SEPARATOR . 'thirstyaffiliates-v3-to-v2-downgrade-add-on' . DIRECTORY_SEPARATOR . 'thirstyaffiliates-v3-to-v2-downgrade-add-on.php';
        $this->_PLUGIN_DIR_PATH       = plugin_dir_path( $this->_MAIN_PLUGIN_FILE_PATH );
        $this->_PLUGIN_DIR_URL        = plugin_dir_url( $this->_MAIN_PLUGIN_FILE_PATH );
        $this->_PLUGIN_BASENAME       = plugin_basename( dirname( $this->_MAIN_PLUGIN_FILE_PATH ) );

        $this->_CSS_ROOT_URL          = $this->_PLUGIN_DIR_URL . 'css/';
        $this->_IMAGES_ROOT_URL       = $this->_PLUGIN_DIR_URL . 'images/';
        $this->_JS_ROOT_URL           = $this->_PLUGIN_DIR_URL . 'js/';

        $this->_VIEWS_ROOT_PATH       = $this->_PLUGIN_DIR_PATH . 'views/';
        $this->_TEMPLATES_ROOT_PATH   = $this->_PLUGIN_DIR_PATH . 'templates/';
        $this->_LOGS_ROOT_PATH        = $this->_PLUGIN_DIR_PATH . 'logs/';

        $main_plugin->add_to_public_helpers( $this );

    }

    public static function get_instance( Abstract_Main_Plugin_Class $main_plugin ) {

        if ( !self::$_instance instanceof self )
            self::$_instance = new self( $main_plugin );
        
        return self::$_instance;

    }

    public function MAIN_PLUGIN_FILE_PATH() {
        return $this->_MAIN_PLUGIN_FILE_PATH;
    }

    public function PLUGIN_DIR_PATH() {
        return $this->_PLUGIN_DIR_PATH;
    }

    public function PLUGIN_DIR_URL() {
        return $this->_PLUGIN_DIR_URL;
    }

    public function PLUGIN_BASENAME() {
        return $this->_PLUGIN_BASENAME;
    }    

    public function CSS_ROOT_URL() {
        return $this->_CSS_ROOT_URL;
    }

    public function IMAGES_ROOT_URL() {
        return $this->_IMAGES_ROOT_URL;
    }

    public function JS_ROOT_URL() {
        return $this->_JS_ROOT_URL;
    }

    public function VIEWS_ROOT_PATH() {
        return $this->_VIEWS_ROOT_PATH;
    }

    public function TEMPLATES_ROOT_PATH() {
        return $this->_TEMPLATES_ROOT_PATH;
    }
    
    public function LOGS_ROOT_PATH() {
        return $this->_LOGS_ROOT_PATH;
    }

}
